"""
@ Author : HotDrify
@ Type : gpt-3.5-turbo
@ GiT : https://github.com/HotDrify/freeAI
"""
import asyncio
import json
import time
from fake_useragent import UserAgent
import aiohttp

headers = {
    "User-Agent": UserAgent().random,
    "Accept": "application/json, text/plain, */*",
    "Accept-Language": "ru-RU,ru;q=0.8,en-US;q=0.5,en;q=0.3",
    "Content-Type": "application/json",
    "Sec-Fetch-Dest": "empty",
    "Sec-Fetch-Mode": "123",
    "Sec-Fetch-Site": "same-origin"
}
class Running:
    @staticmethod
    async def main(q, proxies = None, temperature = 1):
        async with aiohttp.ClientSession(headers=headers) as session:
            async with session.post(
                    "https://mflsf.aitianhu.fun/api/chat-process",
                    json = {
                      "prompt": q,
                      "options": {},
                      "systemMessage": "You are heplful gpt-3 assistant.",
                      "temperature": temperature,
                      "top_p": 1
                    },
                    proxy = proxies
            ) as response:
                text = await response.text()
                lines = text.splitlines()
                out = ""
                for line in lines:
                    try:
                        data = json.loads(line)
                        out = data["text"]
                    except:
                        pass
                if response.ok:
                    output = {
                        "status": ["OK"],
                        "created": time.time(),
                        "model": "GPT-3.5-turbo",
                        "result": [
                            {
                                "prompt": q,
                                "content": out
                            }
                        ]
                    }
                else:
                    output = {
                        "status": [
                            {
                                "code": response.status
                            }
                        ],
                        "created": time.time(),
                        "model": "GPT-3.5-turbo",
                        "result": [
                            {}
                        ]
                    }
        return output


"""
@ Author : HotDrify
@ Type : GPT-3.5-turbo
@ GiT : https://github.com/HotDrify/freeAI
@ taken from gpt4free
"""
import asyncio
import time
from fake_useragent import UserAgent
import aiohttp

headers = {
    "User-Agent": UserAgent().random,
    "authority": "api.aichatos.cloud",
    "origin": "https://chat9.yqcloud.top",
    "referer": "https://chat9.yqcloud.top/"
}

class Running:
    @staticmethod
    async def main(q, proxies=None):
        async with aiohttp.ClientSession(headers=headers) as session:
            async with session.post(
                    "https://api.aichatos.cloud/api/generateStream",
                    json = {
                        "prompt": f"always reply in the user language | {q}",
                        "userId": f"#/chat/{int(time.time() * 1000)}",
                        "network": True,
                        "apikey": "",
                        "system": "",
                        "withoutContext": False
                    },
                    proxy = proxies
            ) as response:
                text = await response.text()
                if response.ok:
                    output = {
                        "status": ["OK"],
                        "created": time.time(),
                        "model": "GPT-3.5-turbo",
                        "result": [
                            {
                                "prompt": q,
                                "content": text
                            }
                        ]
                    }
                else:
                    output = {
                        "status": [
                            {
                                "code": response.status
                            }
                        ],
                        "created": time.time(),
                        "model": "GPT-3.5-turbo",
                        "result": [
                            {}
                        ]
                    }
        return output


"""
@ Author : HotDrify
@ Type : alpaca 7B
@ GiT : https://github.com/HotDrify/freeAI
"""
import asyncio
import time
from fake_useragent import UserAgent
import aiohttp

headers = {
    "User-Agent": UserAgent().random
}

class Running:
    @staticmethod
    async def main(q, proxies=None):
        async with aiohttp.ClientSession(headers=headers) as session:
            async with session.post(
                    "https://us-central1-arched-keyword-306918.cloudfunctions.net/run-inference-1",
                    json = {
                        "prompt": q
                    },
                    proxy = proxies
            ) as response:
                text = await response.json()
                if response.ok:
                    output = {
                        "status": ["OK"],
                        "created": time.time(),
                        "model": "alpaca-7B",
                        "result": [
                            {
                                "prompt": q,
                                "content": text['completion']
                            }
                        ]
                    }
                else:
                    output = {
                        "status": [
                            {
                                "code": response.status
                            }
                        ],
                        "created": time.time(),
                        "model": "alpaca-7B",
                        "result": [
                            {}
                        ]
                    }
        return output


"""
@ Author : HotDrify
@ Type : gpt-3.5-turbo-0301
@ GiT : https://github.com/HotDrify/freeAI
"""
import asyncio
import json
import time
from fake_useragent import UserAgent
import aiohttp

headers = {
    "User-Agent": UserAgent().random,
    "accept": "text/event-stream"
}

class Running:
    @staticmethod
    async def main(messages, proxies = None, temperature = 1):
        async with aiohttp.ClientSession(headers=headers) as session:
            async with session.post(
                    "https://mishalsgpt.vercel.app/api/openai/v1/chat/completions",
                    json = {
                      "messages": messages,
                      "stream": True,
                      "model": "gpt-3.5-turbo",
                      "temperature": temperature,
                      "presence_penalty": 2,
                      "frequency_penalty": 0
                    },
                    proxy = proxies
            ) as response:
                rtext = await response.text()
                text = rtext.replace("data: ", "").replace("\n\n", "\n").rstrip("\n[DONE]")
                lines = text.splitlines()
                resout = ""
                for line in lines:
                    try:
                        data = json.loads(line)
                        resout += data["choices"][0]['delta']['content']
                    except Exception:
                        pass
                if response.ok:
                    output = {
                        "status": ["OK"],
                        "created": time.time(),
                        "model": "GPT-3.5-turbo",
                        "result": [
                            {
                                "messages": messages,
                                "content": resout
                            }
                        ]
                    }
                else:
                    output = {
                        "status": [
                            {
                                "code": response.status
                            }
                        ],
                        "created": time.time(),
                        "model": "GPT-3.5-turbo",
                        "result": [
                            {}
                        ]
                    }
        return output


from setuptools import setup, find_packages

with open("README.md", "r", encoding = "utf-8") as fh:
    README = fh.read()
   
setup(
  name = "hamuna-agent",
  version = "1.0.0",
  url = "https://hamuna.club",
  author = "HotDrify",
  license = "Apache License 2.0",
  keywords = [
    "chatBot",
    "freeAI",
    "freeGPT",
    "freeChatGPT",
    "gptfree",
    "freeAPI",
    "python",
    "api",
  ],
  python_requires = ">=3.7",
  packages=find_packages(),
  install_requires=[
    "aiohttp",
    "fake-useragent",
  ]
)
